﻿-- Функция для изменения трения в зависимости от погодных условий
function adjustWheelFrictionBasedOnWeather(vehicle, isRaining)
    if isRaining then
        -- Уменьшение трения при дожде
        vehicle:setWheelFriction(0.2) -- Пример значения низкого трения
    else
        -- Установка стандартного трения при ясной погоде
        vehicle:setWheelFriction(1.0) -- Пример значения стандартного трения
    end
end

-- Функция для изменения продавливания почвы в зависимости от погоды
function adjustTerrainDisplacement(isRaining)
    if isRaining then
        setTerrainDisplacementLayerMaxHeight(0.8) -- Глубокое продавливание во время дождя
    else
        setTerrainDisplacementLayerMaxHeight(0.4) -- Стандартное продавливание в ясную погоду
    end
end

-- Функция для изменения жесткости поля в зависимости от погоды
function adjustFieldSoftness(isRaining)
    if isRaining then
        -- Уменьшаем жесткость почвы при дожде
        setTerrainResistance(0.3) -- Меньшая жесткость (пример значения)
    else
        -- Устанавливаем стандартную жесткость при ясной погоде
        setTerrainResistance(1.0) -- Стандартная жесткость (пример значения)
    end
end

-- Обработчик обновления погоды
function updateWeather()
    local isRaining = WeatherSystem:isRaining() -- Проверяем, идет ли дождь
    -- Применяем изменения трения для всех транспортных средств
    for _, vehicle in ipairs(VehicleManager:getAllVehicles()) do
        adjustWheelFrictionBasedOnWeather(vehicle, isRaining)
    end
    -- Применяем изменения для почвы
    adjustTerrainDisplacement(isRaining)
    adjustFieldSoftness(isRaining)
end

-- Подключение обработчика к игровому циклу
EventManager:on("weatherUpdate", updateWeather)
